@@ -1,5 +1,5 @@
 egJofF.1dec93.data <- list(
-  input = ts(matrix(c(0, 0.25999999046325861, 
+  input = stats::ts(matrix(c(0, 0.25999999046325861, 
 	1.8399999141693133, 0.53000009059906183, 0.12999999523163019, 
 	-0.12999999523163019, 0.26999998092650834, -0.80000007152557018, 
 	-0.78999996185302912, -0.51999998092651722, 0.51999998092651722, 
@@ -73,7 +73,7 @@ egJofF.1dec93.data <- list(
 	0.52999999999999936, 0.11000000000000032), 236, 1),
   start=c(1974,2), frequency=12),
 
-  output=ts(matrix(c(
+  output=stats::ts(matrix(c(
 	1.0362694300518098, 1.025641025641022, 1.0152284263959355, 
 	1.5075376884422147, 1.2376237623762376, 0.48899755501223191, 
 	0.97323600973235658, 0.96385542168674354, 0.71599045346063073, 
