@@ -42,19 +42,9 @@ guide.example.tests.part1 <- function( verbose=TRUE, synopsis=TRUE, fuzz.small=1
   if (synopsis & !verbose) cat("All Brief User Guide example part 1 tests ...")
 
   if (verbose) cat("Guide part 1 test 0 ... ")
-
-#  from <- paste(DSE.HOME, "/data/eg1.dat", sep="")
-#  eg1.DSE.data <- t(matrix(dsescan(from), 5,364))[,2:5]
-#  eg1.DSE.data <- TSdata(input=tframed(eg1.DSE.data[,1  ,drop=FALSE],
-#                                         list(start=c(1961,3), frequency=12)),
-#              output=tframed(eg1.DSE.data[,2:4,drop=FALSE], 
-#                                         list(start=c(1961,3), frequency=12)))
-# above worked, but needs DSE.HOME which is depreciated. use
-       data("eg1.DSE.data.diff", package="dse1")
-       data("eg1.DSE.data", package="dse1")
-       data("egJofF.1dec93.data", package="dse1")
-        
-   
+  data("eg1.DSE.data.diff", package="dse1")
+  data("eg1.DSE.data", package="dse1")
+  data("egJofF.1dec93.data", package="dse1")   
   if (verbose) { cat("ok\n") }
      
   if (verbose) cat("Guide part 1 test 1 ... ")
@@ -87,9 +77,8 @@ guide.example.tests.part1 <- function( verbose=TRUE, synopsis=TRUE, fuzz.small=1
 # These differences seems fairly large, but the matrix is 14x14 and 
 # the roots are almost identical
 
-  good <- if (is.R()) 
-      c(15.430979953081722655, 3.9469252417636165, 2.4561249653768193468) else
-      c(15.430979953081722655, -1.1078692933906153506, 2.4561249653768193468)
+  good <-     c(15.430979953081722655, 3.9469252417636165, 2.4561249653768193468) 
+ #Splus value c(15.430979953081722655, -1.1078692933906153506, 2.4561249653768193468)
 
   test.value <- c(sum(TSmodel(model1)$A), sum(TSmodel(model2)$F),
                          sum(roots(model2)) )
